@@ -30,8 +30,25 @@ set -x
 MYTEMP_DIR=`mktemp -d`
 ME=`whoami`
 
-mysqld --no-defaults --initialize-insecure --datadir=${MYTEMP_DIR} --user=${ME}
-/usr/sbin/mysqld --no-defaults --user=${ME} --socket=${MYTEMP_DIR}/mysql.sock --datadir=${MYTEMP_DIR} --skip-networking &
+MYSQL_VERSION=`/usr/sbin/mysqld --version 2>/dev/null | grep Ver | awk '{print $3}' | cut -d- -f1`
+MYSQL_VERSION_MAJ=`echo $MYSQL_VERSION | cut -d. -f1`
+MYSQL_VERSION_MID=`echo $MYSQL_VERSION | cut -d. -f2`
+MYSQL_VERSION_MIN=`echo $MYSQL_VERSION | cut -d. -f3`
+
+if [ "${MYSQL_VERSION_MAJ}" -le 5 ] && [ "${MYSQL_VERSION_MID}" -lt 7 ] ; then
+	MYSQL_INSTALL_DB_OPT="--force --skip-name-resolve" 
+else
+	MYSQL_INSTALL_DB_OPT="--basedir=/usr"
+fi
+
+# --force is needed because buildd's can't resolve their own hostnames to ips
+if [ -f /usr/bin/mysql_install_db ]; then
+    mysql_install_db --no-defaults --datadir=${MYTEMP_DIR} ${MYSQL_INSTALL_DB_OPT} --user=${ME}
+else
+    # Use mysqld to create the database directory
+    /usr/sbin/mysqld --no-defaults --initialize --datadir=${MYTEMP_DIR} --skip-name-resolve --user=${ME}
+fi
+/usr/sbin/mysqld --no-defaults --skip-grant-tables --user=${ME} --socket=${MYTEMP_DIR}/mysql.sock --datadir=${MYTEMP_DIR} --skip-networking &
 
 # This sets the path of the MySQL socket for any libmysql-client users, which includes
 # the ./tests/test_dbi client
@@ -39,7 +56,7 @@ export MYSQL_UNIX_PORT=${MYTEMP_DIR}/mysql.sock
 
 echo -n pinging mysqld.
 attempts=0
-while ! /usr/bin/mysqladmin -uroot --socket=${MYTEMP_DIR}/mysql.sock ping ; do
+while ! /usr/bin/mysqladmin --socket=${MYTEMP_DIR}/mysql.sock ping ; do
 	sleep 3
 	attempts=$((attempts+1))
 	if [ ${attempts} -gt 10 ] ; then
@@ -49,28 +66,33 @@ while ! /usr/bin/mysqladmin -uroot --socket=${MYTEMP_DIR}/mysql.sock ping ; do
 done
 
 # Create the db
-mysql -uroot --socket=${MYTEMP_DIR}/mysql.sock --execute="CREATE DATABASE test_pymysql;"
-mysql -uroot --socket=${MYTEMP_DIR}/mysql.sock --execute="CREATE DATABASE test_pymysql2;"
+mysql --socket=${MYTEMP_DIR}/mysql.sock --execute="CREATE DATABASE test_pymysql;"
+mysql --socket=${MYTEMP_DIR}/mysql.sock --execute="CREATE DATABASE test_pymysql2;"
 
 #####################
 ### RUN THE TESTS ###
 #####################
+MULTI_STATEMENTS=$(python3 -c 'from pymysql.constants import CLIENT ; print(CLIENT.MULTI_STATEMENTS)')
 # Launch the tests
 echo "[
-{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql\", \"use_unicode\": true},
-{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql2\" }
+{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql\", \"use_unicode\": true, \"client_flag\": $MULTI_STATEMENTS},
+{\"unix_socket\": \"${MYTEMP_DIR}/mysql.sock\", \"user\": \"root\", \"passwd\": \"\", \"db\": \"test_pymysql2\", \"client_flag\": $MULTI_STATEMENTS }
 ]" >pymysql/tests/databases.json
 
-PYTHONS=`pyversions -vr`
-PYTHON3S=`py3versions -vr`
-for pyvers in $PYTHONS $PYTHON3S; do
-	PYTHONPATH=. PYTHON=python$pyvers python$pyvers runtests.py
-done
+if PYTHONPATH=. PYTHON=$1 $1 -m pytest -v pymysql ; then
+	SUCCESS=0
+	echo "Yeah, ran unit tests..."
+else
+	SUCCESS=1
+	echo "Nei when running unit tests"
+fi
 
 rm pymysql/tests/databases.json
 
 ###############################################
 ### SHUTDOWN MYSQL AND CLEAN ITS TMP FOLDER ###
 ###############################################
-/usr/bin/mysqladmin -uroot --socket=${MYTEMP_DIR}/mysql.sock shutdown
+/usr/bin/mysqladmin --socket=${MYTEMP_DIR}/mysql.sock shutdown
 rm -rf ${MYTEMP_DIR}
+
+exit $SUCCESS
